@@ -35,6 +35,8 @@ DEFAULT_NETWORK_NUM = 1
 OUTPUT_BUFFER_MIN_SIZE = 65535
 OUTPUT_BUFFER_BATCH_MAX_HOLD_TIME = 0.05
 
+FULL_QUOTA_PERCENTAGE = 100
+
 # The unsigned integer transaction SID representing null.
 # If changing, also change in bxapi/constants.py
 NULL_TX_SID = 0
@@ -214,6 +216,7 @@ MSG_HANDLERS_DURATION_WARN_THRESHOLD_S = 0.5
 NETWORK_OPERATION_CYCLE_DURATION_WARN_THRESHOLD_S = 0.2
 NETWORK_OPERATION_DURATION_WARN_THRESHOLD_S = 0.5
 GC_DURATION_WARN_THRESHOLD = 0.1
+TX_SERVICE_SET_TXS_WARN_THRESHOLD = 0.1
 
 # </editor-fold>
 
@@ -298,3 +301,5 @@ TX_SYNC_USE_SNAPSHOT = False
 
 MEM_STATS_OBJECT_SIZE_THRESHOLD = 1024 * 1024
 MEM_STATS_OBJECT_COUNT_THRESHOLD = 2000
+
+TX_FROM_PUB_API_TO_RELAY_THRESHOLD_S = 2.0
