@@ -7,7 +7,9 @@ from bxcommon.models.serializable_flag import SerializableFlag
 class NodeType(SerializableFlag):
     INTERNAL_GATEWAY = enum.auto()
     EXTERNAL_GATEWAY = enum.auto()
-    GATEWAY = INTERNAL_GATEWAY | EXTERNAL_GATEWAY  # deprecated, use GATEWAY_TYPE for abstract gateway, # GATEWAY for v1.0 gateways
+    # deprecated, use GATEWAY_TYPE for abstract gateway,
+    # GATEWAY for v1.0 gateways
+    GATEWAY = INTERNAL_GATEWAY | EXTERNAL_GATEWAY
     GATEWAY_TYPE = GATEWAY
     RELAY_TRANSACTION = enum.auto()
     RELAY_BLOCK = enum.auto()
@@ -15,6 +17,7 @@ class NodeType(SerializableFlag):
     RELAY_TYPE = RELAY  # use RELAY_TYPE for abstract relay, use RELAY for `non split` relay
     API = enum.auto()
     API_SOCKET = enum.auto()
+    BLOXROUTE_PUBLIC_API = enum.auto()
 
     def get_subtypes(self) -> Iterable["NodeType"]:
         for subtype in self.__class__:
