@@ -7,6 +7,8 @@ from bxutils import logging
 from bxutils.logging import LogRecordType
 
 if TYPE_CHECKING:
+    # noinspection PyUnresolvedReferences
+    # pylint: disable=ungrouped-imports,cyclic-import
     from bxcommon.connections.abstract_node import AbstractNode
 
 network_troubleshooting_logger = logging.get_logger(LogRecordType.NetworkTroubleshooting, __name__)
@@ -22,9 +24,10 @@ class SocketConnectionProtocol(AbstractSocketConnectionProtocol, BufferedProtoco
     ):
         AbstractSocketConnectionProtocol.__init__(self, node, endpoint, is_ssl)
 
-    def get_buffer(self, _suggested_size: int):
+    # pylint: disable=arguments-differ
+    def get_buffer(self, _sizehint: int):
         return self._receive_buf
 
-    def buffer_updated(self, bytes_len: int):
+    def buffer_updated(self, nbytes: int):
         if self.is_receivable():
-            self._node.on_bytes_received(self.file_no, self._receive_buf[:bytes_len])
+            self._node.on_bytes_received(self.file_no, self._receive_buf[:nbytes])
