@@ -8,15 +8,14 @@ from urllib3.exceptions import HTTPError, MaxRetryError
 from urllib3.poolmanager import PoolManager
 from urllib3.util import parse_url
 
-from bxutils import log_messages
-
 from bxcommon import constants
+from bxutils import log_messages
 from bxutils import logging
 from bxutils.encoding import json_encoder
 
 # recursive types are not supported: https://github.com/python/typing/issues/182
 
-jsonT = Union[Dict[str, Any], List[Any]]
+JT = Union[Dict[str, Any], List[Any]]
 
 logger = logging.get_logger(__name__)
 
@@ -29,36 +28,43 @@ METHODS_WHITELIST = frozenset(
 
 
 def set_root_url(sdn_url: str, ssl_context: Optional[SSLContext] = None):
+    # pylint: disable=global-statement
     global _url
     _url = sdn_url
     update_http_ssl_context(ssl_context)
 
 
 def update_http_ssl_context(ssl_context: Optional[SSLContext] = None):
+    # pylint: disable=global-statement
     global _ssl_context
     _ssl_context = ssl_context
 
 
-def post_json(endpoint: str, payload=None) -> Optional[jsonT]:
+def post_json(endpoint: str, payload=None) -> Optional[JT]:
     return _http_request("POST", endpoint, body=json_encoder.to_json(payload),
                          headers=constants.HTTP_HEADERS)
 
 
-def patch_json(endpoint: str, payload=None) -> Optional[jsonT]:
+def patch_json(endpoint: str, payload=None) -> Optional[JT]:
     return _http_request("PATCH", endpoint, body=json_encoder.to_json(payload),
                          headers=constants.HTTP_HEADERS)
 
 
-def delete_json(endpoint: str, payload=None) -> Optional[jsonT]:
+def delete_json(endpoint: str, payload=None) -> Optional[JT]:
     return _http_request("DELETE", endpoint, body=json_encoder.to_json(payload),
                          headers=constants.HTTP_HEADERS)
 
 
-def get_json(endpoint: str) -> Optional[jsonT]:
+def get_json(endpoint: str) -> Optional[JT]:
     return _http_request("GET", endpoint,
                          headers=constants.HTTP_HEADERS)
 
 
+def get_json_with_payload(endpoint: str, payload=None) -> Optional[JT]:
+    return _http_request("GET", endpoint, body=json_encoder.to_json(payload),
+                         headers=constants.HTTP_HEADERS)
+
+
 def build_url(endpoint: str) -> str:
     if not endpoint or not isinstance(endpoint, str):
         raise ValueError("Missing or invalid URL")
@@ -67,10 +73,10 @@ def build_url(endpoint: str) -> str:
 
 def raise_for_status(res: HTTPResponse) -> None:
     if status.is_client_error(res.status) or status.is_server_error(res.status):
-        raise HTTPError("{}:{}", res.status, res.reason)
+        raise HTTPError(f"{res.status}:{res.reason}")
 
 
-def _http_request(method: str, endpoint: str, **kwargs) -> Optional[jsonT]:
+def _http_request(method: str, endpoint: str, **kwargs) -> Optional[JT]:
     url = build_url(endpoint)
     parsed_url = parse_url(url)
     pm_args = {
@@ -101,7 +107,7 @@ def _http_request(method: str, endpoint: str, **kwargs) -> Optional[jsonT]:
     except MaxRetryError as e:
         logger.info("{} to {} failed due to: {}.", method, url, e)
         return None
-    except Exception as e:
+    except Exception as e:  # pylint: disable=broad-except
         logger.error(log_messages.HTTP_REQUEST_RETURNED_ERROR, method, url, e)
         return None
 
