@@ -1,4 +1,4 @@
-class ThroughputEvent(object):
+class ThroughputEvent:
     def __init__(self, direction, msg_type, msg_size, peer_desc):
         self.direction = direction
         self.msg_type = msg_type
