@@ -51,12 +51,14 @@ class AbstractFormatter(Formatter):
     instance: str = NO_INSTANCE
 
     def _handle_args(self, record):
-        if record.args and isinstance(record.args[0], str) and record.args[0] == constants.HAS_PREFIX:
-            prefix = record.args[1]
-            r_args = record.args[2:]
-            return " ".join([prefix, self._formatter(record.msg, r_args)])
-        else:
-            return self._formatter(record.msg, record.args)
+        try:
+            if record.args and isinstance(record.args[0], str) and record.args[0] == constants.HAS_PREFIX:
+                prefix = record.args[1]
+                r_args = record.args[2:]
+                return " ".join([prefix, self._formatter(record.msg, r_args)])
+        except KeyError:
+            pass
+        return self._formatter(record.msg, record.args)
 
 
 class JSONFormatter(AbstractFormatter):
