@@ -32,10 +32,9 @@ from bxgateway.services.push_block_queuing_service import PushBlockQueuingServic
 from bxgateway.testing.eth_lossy_relay_connection import EthLossyRelayConnection
 from bxgateway.testing.test_modes import TestModes
 from bxgateway.utils.eth import crypto_utils
-from bxgateway.utils.eth.remote_header_request import RemoteHeaderRequest
 from bxgateway.utils.stats.eth.eth_gateway_stats_service import eth_gateway_stats_service
 from bxutils import logging
-from bxgateway import log_messages
+from bxgateway import log_messages, eth_constants
 from bxutils.services.node_ssl_service import NodeSSLService
 
 logger = logging.get_logger(__name__)
@@ -65,7 +64,7 @@ class EthGatewayNode(AbstractGatewayNode):
     }
 
     def __init__(self, opts, node_ssl_service: NodeSSLService):
-        super(EthGatewayNode, self).__init__(opts, node_ssl_service)
+        super(EthGatewayNode, self).__init__(opts, node_ssl_service, eth_constants.TRACKED_BLOCK_CLEANUP_INTERVAL_S)
 
         self._node_public_key = None
         self._remote_public_key = None
@@ -85,9 +84,6 @@ class EthGatewayNode(AbstractGatewayNode):
         self.block_processing_service: EthBlockProcessingService = EthBlockProcessingService(self)
         self.block_queuing_service: EthBlockQueuingService = EthBlockQueuingService(self)
 
-        # queue to track header requests to remote blockchain node
-        self.requested_remote_headers_queue: Deque[RemoteHeaderRequest] = deque()
-
         # List of know total difficulties, tuples of values (block hash, total difficulty)
         self._last_known_difficulties = deque(maxlen=eth_constants.LAST_KNOWN_TOTAL_DIFFICULTIES_MAX_COUNT)
 
@@ -242,17 +238,18 @@ class EthGatewayNode(AbstractGatewayNode):
 
         return block_total_difficulty
 
-    def log_requested_remote_blocks(self, block_hashes: List[memoryview]) -> None:
+    def log_requested_remote_blocks(self, block_hashes: List[Sha256Hash]) -> None:
         if self._skip_remote_block_requests_stats_count > 0:
             self._skip_remote_block_requests_stats_count -= 1
         else:
             for block_hash in block_hashes:
-                block_stats.add_block_event_by_block_hash(block_hash,
-                                                          BlockStatEventType.REMOTE_BLOCK_REQUESTED_BY_GATEWAY,
-                                                          network_num=self.network_num,
-                                                          more_info="Protocol: {}, Network: {}".format(
-                                                              self.opts.blockchain_protocol,
-                                                              self.opts.blockchain_network))
+                block_stats.add_block_event_by_block_hash(
+                    block_hash,
+                    BlockStatEventType.REMOTE_BLOCK_REQUESTED_BY_GATEWAY,
+                    network_num=self.network_num,
+                    more_info=f"Protocol: {self.opts.blockchain_protocol}, "
+                              f"Network: {self.opts.blockchain_network}"
+                )
             self._requested_remote_blocks_queue.append(block_hashes)
 
     def log_received_remote_blocks(self, blocks_count: int) -> None:
