@@ -92,7 +92,12 @@ RELAY_CONNECTION_REEVALUATION_INTERVAL_S = 4 * 60 * 60
 
 BLOCK_QUEUE_LENGTH_LIMIT = 128
 
+QUOTA_NOTIFICATION_IGNORE_REPEAT_WINDOW_S = 60
+
 
 LOCALHOST = "127.0.0.1"
 
 TRACKED_BLOCK_MAX_HASH_LOOKUP = 100
+
+BDN_TX_PROCESSING_TIME_WARNING_THRESHOLD_S = 0.05
+BLOCKCHAIN_TX_PROCESSING_TIME_WARNING_THRESHOLD_S = 0.05
