@@ -1,21 +1,21 @@
 from typing import TYPE_CHECKING, Union, List, Dict, Any
 from aiohttp.web_response import Response
 from aiohttp.web_exceptions import HTTPOk
-from bxgateway.rpc.gateway_status_details_level import GatewayStatusDetailsLevel
 
+from bxgateway.rpc.gateway_status_details_level import GatewayStatusDetailsLevel
 from bxutils.encoding.json_encoder import EnhancedJSONEncoder
 
-from bxgateway.rpc.requests.abstract_rpc_request import AbstractRpcRequest
-from bxgateway.rpc.rpc_request_type import RpcRequestType
+from bxgateway.rpc.requests.abstract_gateway_rpc_request import AbstractGatewayRpcRequest
+from bxcommon.rpc.rpc_request_type import RpcRequestType
 
 if TYPE_CHECKING:
     from bxgateway.connections.abstract_gateway_node import AbstractGatewayNode
 
 
-class GatewayStopRpcRequest(AbstractRpcRequest):
+class GatewayStopRpcRequest(AbstractGatewayRpcRequest):
     help = {
-        "params": "NA",
-        "description": "Shutdown request to the gateway"
+        "params": "",
+        "description": "shutdown request to the gateway"
     }
 
     def __init__(
