@@ -1,5 +1,5 @@
 import typing
-from typing import Iterable
+from typing import Iterable, TYPE_CHECKING
 from abc import abstractmethod
 
 from bxutils import logging
@@ -10,7 +10,9 @@ from bxcommon.utils.object_hash import Sha256Hash
 
 from bxgateway.messages.eth.protocol.new_block_eth_protocol_message import NewBlockEthProtocolMessage
 from bxgateway.services.abstract_block_cleanup_service import AbstractBlockCleanupService
-from bxcommon import constants
+
+if TYPE_CHECKING:
+    from bxgateway.connections.eth.eth_gateway_node import EthGatewayNode
 
 logger = logging.get_logger(LogRecordType.BlockCleanup, __name__)
 
@@ -20,7 +22,6 @@ class AbstractEthBlockCleanupService(AbstractBlockCleanupService):
     Service for managing block cleanup.
     """
 
-    # pyre-fixme[11]: Annotation `EthGatewayNode` is not defined as a type.
     def __init__(self, node: "EthGatewayNode", network_num: int):
         """
         Constructor
@@ -30,25 +31,6 @@ class AbstractEthBlockCleanupService(AbstractBlockCleanupService):
 
         super(AbstractEthBlockCleanupService, self).__init__(node=node, network_num=network_num)
 
-    def block_cleanup_request(self, block_hash: Sha256Hash) -> None:
-        if not self.is_marked_for_cleanup(block_hash):
-            self._block_hash_marked_for_cleanup.add(block_hash)
-            self.last_confirmed_block = block_hash
-            if block_hash in self.node.block_queuing_service._block_parts:
-                self.node.alarm_queue.register_alarm(
-                    constants.MIN_SLEEP_TIMEOUT,
-                    self.clean_block_transactions_from_block_queue,
-                    block_hash)
-
-            elif self.node.node_conn is not None:
-                connection_protocol =\
-                    typing.cast("bxgateway.connections.eth.eth_node_connection_protocol.EthNodeConnectionProtocol",
-                                self.node.node_conn.connection_protocol)
-                connection_protocol.request_block_body([block_hash])
-                logger.trace("Block cleanup request for {}", block_hash)
-            else:
-                logger.debug("Block cleanup for '{}' failed. No connection to node.", repr(block_hash))
-
     def clean_block_transactions(
             self,
             block_msg: NewBlockEthProtocolMessage,
@@ -82,3 +64,10 @@ class AbstractEthBlockCleanupService(AbstractBlockCleanupService):
             transaction_service: TransactionService
          ) -> None:
         pass
+
+    def _request_block(self, block_hash: Sha256Hash):
+        connection_protocol = \
+            typing.cast("bxgateway.connections.eth.eth_node_connection_protocol.EthNodeConnectionProtocol",
+                        self.node.node_conn.connection_protocol)
+        connection_protocol.request_block_body([block_hash])
+        logger.trace("Block cleanup request for {}", block_hash)
